"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const React = require("react");
const styles = require("../../style.scss");
exports.useOnResize = (ref, onResize) => {
    React.useEffect(() => {
        let timer = NaN;
        const callback = () => {
            if (!isNaN(timer)) {
                window.clearTimeout(timer);
            }
            if (ref.current) {
                timer = window.setTimeout(() => {
                    onResize({
                        width: ref.current.clientWidth,
                        height: ref.current.clientHeight,
                    });
                }, 300);
            }
        };
        callback();
        if (typeof window !== "undefined") {
            window.addEventListener("resize", callback);
        }
        return () => {
            if (typeof window !== "undefined") {
                window.removeEventListener("resize", callback);
            }
        };
    }, []);
};
exports.Dendrogram = (props) => {
    const svgRef = React.useRef(null);
    exports.useOnResize(svgRef, props.onResize);
    return (React.createElement("svg", Object.assign({ className: styles.background, ref: svgRef }, props.svg), props.children));
};
exports.Component = exports.Dendrogram;
//# sourceMappingURL=Dendrogram.js.map