"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const React = require("react");
const TreeNode = require("./TreeNode");
const getTransform = (position) => {
    return `translate(${position.y}, ${position.x})`;
};
const generateProps = (store, targetNode) => {
    const position = {
        x: targetNode.x * store.position.scale.x + store.position.offset.x,
        y: targetNode.y * store.position.scale.y + store.position.offset.y,
    };
    const isLastNode = !!targetNode.children && targetNode.children.length > 0;
    const isFirstNode = targetNode.parent === null;
    const sign = isFirstNode || isLastNode ? -1 : 1;
    return {
        g: {
            transform: getTransform(position),
        },
        circle: {
            r: store.radius,
        },
        text: {
            dx: sign * 2 * store.radius,
            dy: store.text.offset,
            textAnchor: isFirstNode || isLastNode ? "end" : "start",
            onClick: () => {
                store.updateKey(targetNode.data.name);
            },
            children: targetNode.data.name,
        },
    };
};
exports.Container = ({ store }) => {
    if (!store.canShow) {
        return null;
    }
    return (React.createElement(React.Fragment, null, store.nodes.map((node, idx) => {
        return React.createElement(TreeNode.Component, Object.assign({}, generateProps(store, node), { key: `node-${idx}` }));
    })));
};
//# sourceMappingURL=Container.js.map